@@ -166,7 +166,7 @@ func (a *Actuator) Delete(ctx context.Context, cluster *clusterv1.Cluster, machi
 		switch host.Status.Provisioning.State {
 		case bmh.StateRegistrationError, bmh.StateRegistering,
 			bmh.StateMatchProfile, bmh.StateInspecting,
-			bmh.StateReady, bmh.StateValidationError:
+			bmh.StateReady, bmh.StateProvisioningError:
 			// Host is not provisioned
 			waiting = false
 		case bmh.StateExternallyProvisioned:
